# Genetic values

For some background, see {ref}`definitions`.

```{eval-rst}
.. autoclass:: fwdpy11.DiploidGeneticValue
    :members: shape, genetic_values, maps_to_fitness, maps_to_trait_value
```

```{eval-rst}
.. autoclass:: fwdpy11.Additive
    :members: asdict, fromdict, asblack, shape, genetic_values, maps_to_fitness, maps_to_trait_value
```

```{eval-rst}
.. autoclass:: fwdpy11.Multiplicative
    :members: asdict, fromdict, asblack, shape, genetic_values, maps_to_fitness, maps_to_trait_value
```

```{eval-rst}
.. autoclass:: fwdpy11.GBR
    :members: asdict, fromdict, asblack, shape, genetic_values, maps_to_fitness, maps_to_trait_value
```

```{eval-rst}
.. autoclass:: fwdpy11.StrictAdditiveMultivariateEffects
    :members: asdict, fromdict, asblack, shape, genetic_values, maps_to_fitness, maps_to_trait_value
```


